
## WordPress Themes

Our WordPress themes use Sass for CSS and ES6 syntax for JavaScript. Both are compiled into versions browsers understand. A /dist directory containing compiled files is available in each theme's GitHub repository. Compilation is done with NPM packages declared as dependencies of the current project.

### File Structure

At minimum, a Colby College WordPress theme should have the following files and folders:

```
root
|   .deploy-servers.js (Configuration for branch-server pairings. Used by the node-autodeploy-wp NPM package. Add to .gitignore to keep the information secure.)
|   .deploy-settings.js (Settings for the deployment step. Used by the node-autodeploy-wp NPM package.)
|   .eslintrc.js
|   .gitignore
|   404.php
|   archive.php
|   functions.php
|   index.php
|   package.json
│   README.md
│   style.css (Empty except for theme information.)
│
└───assets (Static non-JS, non-CSS files such as images and videos.)
|
└───dist (Automatically generated JS and CSS files.)
|
└───src (Static non-JS, non-CSS files such as images and videos.)
|
└──────js
|         index.js (JavaScript entry point for transpiling.)
|
└──────sass
|         main.scss (Sass entry point.)
│   
└───templates (WP templates that aren't required to be in the root.)
|
└───tests
|
└───wp-autoload (Files that will be automatically loaded from functions.php.)
```
### NPM Dependencies

The following should be included as NPM dev dependencies in most projects: 

- [babel-cli](https://github.com/babel/babel/tree/master/packages/babel-cli), [babel-core](https://github.com/babel/babel/tree/master/packages/babel-core), [babel-preset-node6](https://www.npmjs.com/package/babel-preset-node6): Allows development scripts to be written in ES6.
- [bootstrap](https://github.com/twbs/bootstrap/tree/v4-dev) (4.0 and above; using bootstrap@4.0.0-alpha.6 as of 4/2017): Provides Sass mixins and CSS classes for use throughout themes. 
- [colby-gulp](https://github.com/johnwatkins0/colby-gulp): Handles the transpiling of JS, the compiling of Sass, and other automated tasks.
- [copy-index-php-files-from-node-modules](https://github.com/johnwatkins0/copy-index-php-files-from-node-modules): Copies WordPress files from NPM dependencies into the wp-autoload directory.
- [eslint](https://github.com/eslint/eslint): Ensures the JavaScript in the project follows prescribed standards.
- [husky](https://github.com/typicode/husky): Allows the managing of Git Hooks through NPM scripts. 
- [node-autodeploy-wp](https://github.com/johnwatkins0/copy-index-php-files-from-node-modules): Handles autodeployment when branches associated with servers are committed to.

The following dev dependencies are commonly used: 

- [@vimeo/player](https://github.com/vimeo/player.js): Provides interaction with the Vimeo JavaScript API.
- [react](https://github.com/facebook/react), [react-dom](https://github.com/facebook/react/tree/master/packages/react-dom): For projects containing their own React components.
- [vanilla-lazyload](https://github.com/verlok/lazyload): Easy lazyloading of below-the-fold images. 
- [waypoints](https://github.com/imakewebthings/waypoints): Make things happen when elements enter the viewport.

The following dependencies are used in most projects: 
- [colby-templates](https://github.com/ColbyCommunications/colby-templates): Commonly used WordPress parts. 


